pub enum Channel {
Email,
Sms,
PhoneNote,
Portal,
Internal,
}Expand description
Message channel used for customer, staff, portal, phone-note, or internal communication.
Variants
Email message direction, channel, approval state, or delivery state.
Sms
Sms message direction, channel, approval state, or delivery state.
PhoneNote
Phone note message direction, channel, approval state, or delivery state.
Portal
Portal message direction, channel, approval state, or delivery state.
Internal
Internal message direction, channel, approval state, or delivery state.