pub enum Direction {
InboundReceived,
OutboundDraft,
OutboundQueued,
OutboundSent,
}Expand description
Direction of a message relative to the resort operation: inbound, outbound draft, queued, or sent.
Variants
InboundReceived
Inbound received message direction, channel, approval state, or delivery state.
OutboundDraft
Outbound draft message direction, channel, approval state, or delivery state.
OutboundQueued
Outbound queued message direction, channel, approval state, or delivery state.
OutboundSent
Outbound sent message direction, channel, approval state, or delivery state.