pub enum Status {
DraftCreated,
ApprovalRequested,
ApprovedToQueue,
Queued,
SendAttempted,
Delivered,
Failed,
Suppressed,
Cancelled,
}Expand description
Normalized lifecycle states used to reconcile source-system data with domain workflows.
Variants
DraftCreated
Draft created message direction, channel, approval state, or delivery state.
ApprovalRequested
Approval requested message direction, channel, approval state, or delivery state.
ApprovedToQueue
Approved to queue message direction, channel, approval state, or delivery state.
Queued
Queued message direction, channel, approval state, or delivery state.
SendAttempted
Send attempted message direction, channel, approval state, or delivery state.
Delivered
Delivered message direction, channel, approval state, or delivery state.
Failed
Deposit collection was attempted but did not succeed.
Suppressed
Suppressed message direction, channel, approval state, or delivery state.
Cancelled
Reservation is no longer active.